@@ -30,7 +30,7 @@ import (
 )
 
 const (
-	version             = "0.5.2"
+	version             = "0.5.3"
 	nsBOSH              = "urn:xmpp:alt-connections:xbosh"
 	nsC2SdTLS           = "urn:xmpp:alt-connections:tls"
 	nsC2SQuic           = "urn:xmpp:alt-connections:quic"
@@ -865,9 +865,8 @@ func checkBOSH(server string, target string, ipv4 bool, ipv6 bool, tlsConfig *tl
 		return
 	}
 	bodyXML := `<body content='text/xml; charset=utf-8' hold='1' rid='` + getID() +
-		`' to='` + server + `' ver='1.6' wait='` +
-		fmt.Sprintf("%.0f", timeout.Seconds()) +
-		`' ack='1' xml:lang='en' xmlns='` + nsHTTPBind + `'/>`
+		`' to='` + server + `' ver='1.6' wait='0' ack='1' xml:lang='en'` +
+		` xmlns='` + nsHTTPBind + `'/>`
 	body := []byte(bodyXML)
 	req, err := http.NewRequest("POST", target, bytes.NewBuffer(body))
 	if err != nil {
@@ -917,8 +916,13 @@ func checkBOSH(server string, target string, ipv4 bool, ipv6 bool, tlsConfig *tl
 			boshOpen.From, server)
 		return
 	}
-	fmt.Print(statusOK)
-	printTLSVersion(resp.TLS.Version)
+	if resp.TLS != nil {
+		fmt.Print(statusOK)
+		printTLSVersion(resp.TLS.Version)
+	} else {
+		fmt.Printf("%s (%sno TLS%s)", statusNOK, colorRed, colorReset)
+	}
+	fmt.Println()
 }
 
 func checkWebSocket(server string, target string, tlsConfig *tls.Config, timeout time.Duration, targetType string) {
@@ -1004,14 +1008,18 @@ func checkWebSocket(server string, target string, tlsConfig *tls.Config, timeout
 			wsOpen.From, server)
 		return
 	}
-	fmt.Print(statusOK)
 	if resp.TLS != nil {
+		fmt.Print(statusOK)
 		printTLSVersion(resp.TLS.Version)
+		fmt.Println()
 	} else {
 		state := getTLS(wsConn)
 		if state != nil {
+			fmt.Print(statusOK)
 			printTLSVersion(state.Version)
+			fmt.Println()
 		} else {
+			fmt.Printf("%s (%sno TLS%s)", statusNOK, colorRed, colorReset)
 			fmt.Println()
 		}
 	}
@@ -1076,23 +1084,30 @@ func checkCertExpiry(c *tls.Conn) {
 	expiry := c.ConnectionState().PeerCertificates[0].NotAfter
 	start := c.ConnectionState().PeerCertificates[0].NotBefore
 	now := time.Now()
-	if now.Before(expiry) && now.After(start) {
+	switch {
+	case time.Until(expiry).Hours() < 336:
+		fmt.Printf("%s[OK]%s", colorYellow, colorReset)
+		printTLSVersion(c.ConnectionState().Version)
+		fmt.Printf(" (Cert expires in %d days.)\n", int(time.Until(expiry).Hours())%24)
+	case now.Before(expiry) && now.After(start):
 		fmt.Print(statusOK)
-	} else {
+		printTLSVersion(c.ConnectionState().Version)
+		fmt.Println()
+	default:
 		fmt.Print(statusNOK)
-		fmt.Print("Valid from", start, "to", expiry)
+		printTLSVersion(c.ConnectionState().Version)
+		fmt.Printf(" (valid from %s to %s)", start, expiry)
 	}
-	printTLSVersion(c.ConnectionState().Version)
 }
 
 func printTLSVersion(tv uint16) {
 	switch tv {
 	case tls.VersionTLS13:
-		fmt.Printf(" (%s%s%s)\n", colorGreen, tls.VersionName(tv), colorReset)
+		fmt.Printf(" (%s%s%s)", colorGreen, tls.VersionName(tv), colorReset)
 	case tls.VersionTLS12:
-		fmt.Printf(" (%s%s%s)\n", colorYellow, tls.VersionName(tv), colorReset)
+		fmt.Printf(" (%s%s%s)", colorYellow, tls.VersionName(tv), colorReset)
 	default:
-		fmt.Printf(" (%s%s%s)\n", colorRed, tls.VersionName(tv), colorReset)
+		fmt.Printf(" (%s%s%s)", colorRed, tls.VersionName(tv), colorReset)
 	}
 }
 
